==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/user/messages/pl/base.php <==
<?php

return [
    '<strong>Followers</strong>' => '<strong>Obserwowani</strong> przez użytkownika',
    '<strong>Following</strong>' => '<strong>Obserwujący</strong> użytkownika',
    '<strong>Group</strong> members - {group}' => '<strong>Użytkownicy</strong> grupy - {group}',
    '<strong>Member</strong> in these spaces' => '<strong>Członek</strong> stref',
    '<strong>Member</strong> of these Spaces' => '<strong>Członkowie</strong> tych Stref',
    '<strong>People</strong>' => '<strong>Ludzie</strong>',
    '<strong>User</strong> tags' => '<strong>Tagi</strong> użytkownika',
    'All' => 'Wszystko',
    'Allows access to your about page with personal information' => 'Pozwala na dostęp do strony O Mnie z osobistymi informacjami',
    'Any' => 'Dowolny',
    'Auth Mode' => 'Tryb autoryzacji',
    'Basic Settings' => 'Podstawowe ustawienia',
    'Change Email' => 'Zmień adres e-mail',
    'Change Password' => 'Zmień hasło',
    'Change Username' => 'Zmień nazwę użytkownika',
    'Confirm new password' => 'Potwierdź nowe hasło',
    'Connect account' => 'Połącz konto',
    'Connected Accounts' => 'Połączone konta',
    'Connected accounts' => 'Połączone konta',
    'Created at' => 'Utworzone o',
    'Created by' => 'Utworzone przez',
    'Current password' => 'Obecne hasło',
    'Currently in use' => 'Obecnie w użyciu',
    'Default Group' => 'Domyślna Grupa',
    'Default Space' => 'Domyślna strefa',
    'Delete' => 'Usuń',
    'Delete Account' => 'Usuń konto',
    'Description' => 'Opis',
    'Disconnect account' => 'Odłacz konto',
    'E-Mail is already in use! - Try forgot password.' => 'Ten e-mail jest już w użyciu! - Spróbuj opcji przywracania hasła.',
    'Email' => 'E-mail',
    'Enable Notifications' => 'Włącz Powiadomienia',
    'Find people by their profile data or user tags' => 'Znajdź ludzi po informacjach profilowych lub znaczniku użytkownika',
    'Follow' => 'Obserwuj',
    'Followers' => 'Obserwujący',
    'Following' => 'Obserwowani',
    'Force password change upon first login' => 'Wymuś zmianę hasła po pierwszym zalogowaniu',
    'Force password change upon next login' => 'Wymuś zmianę hasła po kolejnym zalogowaniu',
    'Friends' => 'Znajomi',
    'General' => 'Ogólne',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Tutaj możesz się połączyć z zewnętrznymi dostawcami i użyć zewnętrznych usług takich jak autoryzacja single sign.',
    'Language' => 'Język',
    'Last Login' => 'Ostatnio Zalogowany',
    'Manager' => 'Menadżer',
    'Missing E-Mail Attribute from AuthClient.' => 'Brakuje atrybutu e-mail z AuthClient.',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Brak atrybutu ID AuthClient z AuthClient.',
    'Modules' => 'Moduły',
    'My Account' => 'Moje konto',
    'Name' => 'Nazwa',
    'New password' => 'Nowe Hasło',
    'No results found!' => 'Brak wyników!',
    'No users found.' => 'Nie znaleziono użytkowników.',
    'Notifications' => 'Powiadomienia',
    'Password' => 'Hasło',
    'Password changed' => 'Hasło zmienione',
    'Password needs to be at least {chars} characters long.' => 'Hasło musi mieć długość conajmniej {chars} znaków.',
    'Pending Requests' => 'Oczekujące Prośby',
    'People' => 'Ludzie',
    'Permission' => 'Powolenia',
    'Profile' => 'Profil',
    'Profile posts only' => 'Tylko posty profilowe',
    'Register now and participate!' => 'Zarejestruj się i dołącz do dyskusji!',
    'Search...' => 'Szukaj...',
    'Security' => 'Bezpieczeństwo',
    'Send invite' => 'Wyślij zaproszenie',
    'Settings' => 'Ustawienia',
    'Show At Registration' => 'Pokaż w trakcie rejestracji',
    'Show all content' => 'Pokaż całą zawartość',
    'Sign in' => 'Zaloguj się',
    'Sign in / up' => 'Zarejestruj się / zaloguj',
    'Sign up' => 'Zarejestruj się',
    'Sign up now' => 'Zapisz się teraz',
    'Sort order' => 'Kierunek segregowania',
    'Source' => 'Źródło',
    'Status' => 'Status',
    'Tags' => 'Tagi',
    'Try other keywords or remove filters.' => 'Spróbuj inne słowa kluczowe lub usuń filtry.',
    'Unknown user status!' => 'Nieznany stan użytkownika!',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Niepowodzenia zalogowania od ostatniej wizyty: {failedLoginAttemptsCount}',
    'Updated at' => 'Zaktualizowane o',
    'Updated by' => 'Zaktualizowane przez',
    'User' => 'Użytkownik',
    'User Group' => 'Grupy Użytkownika',
    'User has been invited.' => 'Użytkownik został zaproszony',
    'Username' => 'Nazwa użytkownika',
    'Username contains invalid characters.' => 'Nazwa użytkownika zawiera niedozwolone znaki.',
    'View your about page' => 'Przeglądaj Twoją stronę O Mnie',
    'Visibility' => 'Widzialność',
    'Visible' => 'Widzialne',
    'Welcome to %appName%' => 'Witaj w %appName%',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Witaj w %appName%. Proszę kliknij poniższy przycisk aby rozpocząć proces rejestracji.',
    'You got an invite' => 'Otrzymałeś zaproszenie',
    'You\'re not registered.' => 'Nie jesteś zarejestrowany.',
    'You\'ve been invited to join {space} on {appName}' => 'Zostałeś zaproszony aby dołączyc do {space} w {appName}',
    'Your account is disabled!' => 'Twoje konto jest wyłączone!',
    'Your account is not approved yet!' => 'Twoje konto nie zostało jeszcze zaakceptowane!',
    'Your are already logged in! - Logout first!' => 'Już jesteś zalogowany! Najpierw się wyloguj!',
    'Your new password must not be equal your current password!' => 'Twoje nowe hasło musi być inne niż aktualne hasło!',
    'invited you to join {name}.' => 'zaprosił Cię do dołączenia do {name}',
    'invited you to join {space} on {name}.' => 'zaprosił Cię do dołączenia do {space} w {name}',
    'or' => 'lub',
    'Allow users to mention you' => '',
    'Invited by' => '',
    'Mentioning' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/user/messages/pl/base.php <==
<?php

return [
    '<strong>Followers</strong>' => '<strong>Obserwujący</strong> użytkownika',
    '<strong>Following</strong>' => '<strong>Obserwowani</strong> użytkownicy',
    '<strong>Member</strong> in these spaces' => '<strong>Członek</strong> stref',
    '<strong>Member</strong> of these Spaces' => '<strong>Członek</strong> tych Stref',
    '<strong>People</strong>' => '<strong>Ludzie</strong>',
    '<strong>User</strong> tags' => '<strong>Tagi</strong> użytkownika',
    'All' => 'Wszystko',
    'Allows access to your about page with personal information' => 'Pozwala na dostęp do strony O Mnie z osobistymi informacjami',
    'Any' => 'Dowolny',
    'Auth Mode' => 'Tryb autoryzacji',
    'Basic Settings' => 'Podstawowe ustawienia',
    'Change Email' => 'Zmień adres e-mail',
    'Change Password' => 'Zmień hasło',
    'Change Username' => 'Zmień nazwę użytkownika',
    'Confirm new password' => 'Potwierdź nowe hasło',
    'Connect account' => 'Połącz konto',
    'Connected Accounts' => 'Połączone konta',
    'Connected accounts' => 'Połączone konta',
    'Created at' => 'Utworzone o',
    'Created by' => 'Utworzone przez',
    'Current password' => 'Obecne hasło',
    'Currently in use' => 'Obecnie w użyciu',
    'Default Group' => 'Domyślna Grupa',
    'Default Space' => 'Domyślna strefa',
    'Delete' => 'Usuń',
    'Delete Account' => 'Usuń konto',
    'Description' => 'Opis',
    'Did you forget your password?' => 'Zapomniałeś hasła?',
    'Disconnect account' => 'Odłacz konto',
    'Edit' => 'Edytuj',
    'Email' => 'E-mail',
    'Enable Notifications' => 'Włącz Powiadomienia',
    'Find people by their profile data or user tags' => 'Znajdź ludzi po informacjach profilowych lub znaczniku użytkownika',
    'Follow' => 'Obserwuj',
    'Followers' => 'Obserwujący',
    'Following' => 'Obserwowani',
    'Force password change upon first login' => 'Wymuś zmianę hasła po pierwszym zalogowaniu',
    'Force password change upon next login' => 'Wymuś zmianę hasła po kolejnym zalogowaniu',
    'Friends' => 'Znajomi',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Tutaj możesz się połączyć z zewnętrznymi dostawcami i użyć zewnętrznych usług takich jak autoryzacja single sign.',
    'If this wasn\'t you, you can disregard this message.' => 'Jeśli to nie byłeś Ty, możesz zignorować tę wiadomość.',
    'Invite by email' => 'Zaproś przez e-mail',
    'Invite by link' => 'Zaproś poprzez link',
    'Invite new people' => 'Zaproś nowych ludzi',
    'Invited by' => 'Zaproszony przez',
    'It looks like you clicked on an invalid password reset link. Please try again.' => 'Wygląda na to, że kliknąłeś nieprawidłowy link do resetowania hasła. Proszę spróbuj ponownie.',
    'Language' => 'Język',
    'Last Login' => 'Ostatnio Zalogowany',
    'Missing E-Mail Attribute from AuthClient.' => 'Brakuje atrybutu e-mail z AuthClient.',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Brak atrybutu ID AuthClient z AuthClient.',
    'Modules' => 'Moduły',
    'My Account' => 'Moje konto',
    'Name' => 'Nazwa',
    'New password' => 'Nowe Hasło',
    'No results found!' => 'Brak wyników!',
    'No users found.' => 'Nie znaleziono użytkowników.',
    'Notifications' => 'Powiadomienia',
    'Password' => 'Hasło',
    'Password changed' => 'Hasło zmienione',
    'Password needs to be at least {chars} characters long.' => 'Hasło musi mieć długość conajmniej {chars} znaków.',
    'Password recovery' => 'Odzyskiwanie hasła',
    'Pending Requests' => 'Oczekujące Prośby',
    'People' => 'Ludzie',
    'Permission' => 'Powolenia',
    'Profile' => 'Profil',
    'Profile posts only' => 'Tylko posty profilowe',
    'Register now and participate!' => 'Zarejestruj się i dołącz do dyskusji!',
    'Search...' => 'Szukaj...',
    'Security' => 'Bezpieczeństwo',
    'Settings' => 'Ustawienia',
    'Show At Registration' => 'Pokaż w trakcie rejestracji',
    'Show all content' => 'Pokaż całą zawartość',
    'Sign in' => 'Zaloguj się',
    'Sign in / up' => 'Zarejestruj się / zaloguj',
    'Sign up' => 'Zarejestruj się',
    'Sign up now' => 'Zapisz się teraz',
    'Sort order' => 'Kierunek segregowania',
    'Source' => 'Źródło',
    'Status' => 'Status',
    'Tags' => 'Tagi',
    'The secure link has been copied in your clipboard!' => 'Bezpieczny link został skopiowany do Twojego schowka!',
    'Try other keywords or remove filters.' => 'Spróbuj inne słowa kluczowe lub usuń filtry.',
    'Unknown user status!' => 'Nieznany stan użytkownika!',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Niepowodzenia zalogowania od ostatniej wizyty: {failedLoginAttemptsCount}',
    'Updated at' => 'Zaktualizowane o',
    'Updated by' => 'Zaktualizowane przez',
    'User' => 'Użytkownik',
    'User Group' => 'Grupy Użytkownika',
    'User has been invited.' => 'Użytkownik został zaproszony',
    'Username' => 'Nazwa użytkownika',
    'Username contains invalid characters.' => 'Nazwa użytkownika zawiera niedozwolone znaki.',
    'View your about page' => 'Przeglądaj Twoją stronę O Mnie',
    'Visibility' => 'Widzialność',
    'Visible' => 'Widzialne',
    'Welcome to %appName%' => 'Witaj w %appName%',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Witaj w %appName%. Proszę kliknij poniższy przycisk aby rozpocząć proces rejestracji.',
    'Whenever a user follows another user.' => 'Za każdym razem, gdy użytkownik obserwuje innego użytkownika.',
    'You got an invite' => 'Otrzymałeś zaproszenie',
    'You tried registering an account with %appName%, but already have an account associated with this email address.' => 'Próbowałeś zarejestrować konto w %appName%, ale masz już konto powiązane z tym adresem e-mail.',
    'You\'re not registered.' => 'Nie jesteś zarejestrowany.',
    'You\'ve been invited to join {space} on {appName}' => 'Zostałeś zaproszony aby dołączyc do {space} w {appName}',
    'Your account is disabled!' => 'Twoje konto jest wyłączone!',
    'Your account is not approved yet!' => 'Twoje konto nie zostało jeszcze zaakceptowane!',
    'Your are already logged in! - Logout first!' => 'Już jesteś zalogowany! Najpierw się wyloguj!',
    'Your new password must not be equal your current password!' => 'Twoje nowe hasło musi być inne niż aktualne hasło!',
    'invited you to join {name}.' => 'zaprosił Cię do dołączenia do {name}',
    'invited you to join {space} on {name}.' => 'zaprosił Cię do dołączenia do {space} w {name}',
    'or' => 'lub',
    'Advanced Profile Search' => '',
    'Allow users to mention you' => '',
    'Block user' => '',
    'Empty password cannot be saved!' => '',
    'Following (User)' => '',
    'Group Manager(s)' => '',
    'Mentioning' => '',
    'Offline' => '',
    'Online' => '',
    'The Group Manager can approve pending registrations of this group.' => '',
    'The user has been blocked for you.' => '',
    'The user has been unblocked for you.' => '',
    'Unblock user' => '',
];
